@@ -1,6 +1,6 @@
 
 /*
- * $Id: net_db.c,v 1.31.2.17 1997/04/23 19:38:42 wessels Exp $
+ * $Id: net_db.c,v 1.31.2.20 1997/12/01 18:07:55 wessels Exp $
  *
  * DEBUG: section 37    Network Measurement Database
  * AUTHOR: Duane Wessels
@@ -167,6 +167,11 @@ netdbPurgeLRU(void)
     int removed = 0;
     list = xcalloc(meta_data.netdb_addrs, sizeof(netdbEntry *));
     for (n = netdbGetFirst(addr_table); n; n = netdbGetNext(addr_table)) {
+	if (n->rtt == 0 && n->next_ping_time < squid_curtime) {
+	    netdbRelease(n);
+	    removed++;
+	    continue;
+	}
 	*(list + list_count) = n;
 	list_count++;
 	if (list_count > meta_data.netdb_addrs)
@@ -651,3 +656,15 @@ netdbUpdatePeer(request_t * r, peer * e, int irtt, int ihops)
 	(QS) sortPeerByRtt);
 #endif
 }
+
+void
+netdbDeleteAddrNetwork(struct in_addr addr)
+{
+#if USE_ICMP
+    netdbEntry *n = netdbLookupAddr(addr);
+    if (n == NULL)
+	return;
+    debug(37,1,"netdbDeleteAddrNetwork: %s\n", n->network);
+    netdbRelease(n);
+#endif
+}
